/*!
  Header cu definitii utile in depanarea proceselor copil

 @author Dascalu Laurentiu

 Copyright (C) 2010 SO (http://cs.pub.ro/~so/)

 This program is free software; you can redistribute it and
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 3
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef CHILD_UTIL_H_
#define CHILD_UTIL_H_

#include <stdio.h>
#include <stdlib.h>

/*
 * @brief Functii macro pentru scrierea la iesirile standard STDOUT si STDERR.
 */
#define PRINT_STDOUT(...)      fprintf(stdout, __VA_ARGS__);
#define PRINT_STDERR(...)      fprintf(stderr, __VA_ARGS__);

#ifdef _WIN32
#include <windows.h>
#define my_sleep Sleep
#else
#include <unistd.h>
#define my_sleep usleep
#endif

/**
 * @brief Functie macro utila pentru simplificarea codului
 * de tratare a erorilor
 */
#define CHECK(call, op, success_code, call_description, exit_code) \
	if (!((call) op success_code)) \
	{\
		fprintf(stderr,"( %s  linia   %d ) Eroare la ", __FILE__ , __LINE__);\
		perror(call_description);\
		exit(exit_code);\
	}

#define SECONDS                   (1000)
#define HOURS        (60 * 60 * SECONDS)

#define FINAL_WORK()\
do\
{\
	PRINT_STDOUT("Work loop\n");\
	fflush(stdout);\
	while(1)\
		;\
}\
while(0)

#endif /* CHILD_UTIL_H_ */
